import { defineNuxtModule, createResolver, addImports, addPlugin } from '@nuxt/kit';
import { defu } from 'defu';

const module = defineNuxtModule({
  meta: {
    name: "@pinia-plugin-persistedstate/nuxt",
    configKey: "piniaPersistedstate",
    compatibility: {
      nuxt: ">=3.0.0",
      bridge: false
    }
  },
  defaults: {
    storage: "cookies",
    debug: false,
    cookieOptions: {}
  },
  setup(options, nuxt) {
    const { resolve } = createResolver(import.meta.url);
    nuxt.options.build.transpile.push(resolve("./runtime"));
    nuxt.options.runtimeConfig.public.persistedState = defu(nuxt.options.runtimeConfig.public.persistedState, options);
    addImports({
      name: "persistedState",
      from: resolve("./runtime/storages")
    });
    nuxt.hook("modules:done", () => {
      addPlugin(resolve("./runtime/plugin"), { append: true });
    });
  }
});

export { module as default };
